@@ -67,7 +67,8 @@ def upload(ctx, **kwargs):
 
                 def read_callback(monitor):
                     if config_data.get('verbose') == 1:
-                        sys.stdout.write("\r UPLOADING:{0}{1}".format("|" * (monitor.bytes_read * 100 // monitor.len), '%.2f%%' % (monitor.bytes_read * 100 // monitor.len)))
+                        sys.stdout.write("\r UPLOADING:{0}{1}".format(
+                            "|" * (monitor.bytes_read * 100 // monitor.len), '%.2f%%' % (monitor.bytes_read * 100 // monitor.len)))
                         sys.stdout.flush()
                         if monitor.bytes_read / monitor.len == 1:
                             tag[0] += 1
@@ -149,5 +150,3 @@ def download_history(ctx):
 
     """
     pass
-
-
