@@ -13,13 +13,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 #
-
 from flow_sdk.client.api.job import Job
 from flow_sdk.client.api.component import Component
 from flow_sdk.client.api.data import Data
 from flow_sdk.client.api.model import Model
-from flow_sdk.client.api.priviledge import Priviledge
+from flow_sdk.client.api.privilege import Privilege
 from flow_sdk.client.api.queue import Queue
 from flow_sdk.client.api.table import Table
 from flow_sdk.client.api.task import Task
 from flow_sdk.client.api.tag import Tag
+from flow_sdk.client.api.checkpoint import Checkpoint
+from flow_sdk.client.api.version import Version
+from flow_sdk.client.api.test import Test
