@@ -16,7 +16,7 @@
 
 
 from pipeline.backend.pipeline import PipeLine
-from pipeline.component import DataIO
+from pipeline.component import DataTransform
 from pipeline.component import HeteroLR
 from pipeline.component import Intersection
 from pipeline.component import Reader
@@ -55,16 +55,16 @@ def main():
     reader_1.get_party_instance(role="guest", party_id=guest).component_param(table=guest_eval_data)
     reader_1.get_party_instance(role="host", party_id=host).component_param(table=host_eval_data)
 
-    # define DataIO components
-    dataio_0 = DataIO(name="dataio_0")
-    dataio_1 = DataIO(name="dataio_1")
+    # define DataTransform components
+    data_transform_0 = DataTransform(name="data_transform_0")
+    data_transform_1 = DataTransform(name="data_transform_1")
 
-    # get DataIO party instance of guest
-    dataio_0_guest_party_instance = dataio_0.get_party_instance(role="guest", party_id=guest)
-    # configure DataIO for guest
-    dataio_0_guest_party_instance.component_param(with_label=True, output_format="dense")
-    # get and configure DataIO party instance of host
-    dataio_0.get_party_instance(role="host", party_id=host).component_param(with_label=False)
+    # get DataTransform party instance of guest
+    data_transform_0_guest_party_instance = data_transform_0.get_party_instance(role="guest", party_id=guest)
+    # configure DataTransform for guest
+    data_transform_0_guest_party_instance.component_param(with_label=True, output_format="dense")
+    # get and configure DataTransform party instance of host
+    data_transform_0.get_party_instance(role="host", party_id=host).component_param(with_label=False)
 
     # define Intersection components
     intersection_0 = Intersection(name="intersection_0")
@@ -77,12 +77,13 @@ def main():
     # add components to pipeline, in order of task execution
     pipeline.add_component(reader_0)
     pipeline.add_component(reader_1)
-    pipeline.add_component(dataio_0, data=Data(data=reader_0.output.data))
-    # set dataio_1 to replicate model from dataio_0
-    pipeline.add_component(dataio_1, data=Data(data=reader_1.output.data), model=Model(dataio_0.output.model))
+    pipeline.add_component(data_transform_0, data=Data(data=reader_0.output.data))
+    # set data_transform_1 to replicate model from data_transform_0
+    pipeline.add_component(data_transform_1,
+                           data=Data(data=reader_1.output.data), model=Model(data_transform_0.output.model))
     # set data input sources of intersection components
-    pipeline.add_component(intersection_0, data=Data(data=dataio_0.output.data))
-    pipeline.add_component(intersection_1, data=Data(data=dataio_1.output.data))
+    pipeline.add_component(intersection_0, data=Data(data=data_transform_0.output.data))
+    pipeline.add_component(intersection_1, data=Data(data=data_transform_1.output.data))
     # set train & validate data of hetero_lr_0 component
     pipeline.add_component(
         hetero_lr_0,
@@ -101,7 +102,7 @@ def main():
 
     # predict
     # deploy required components
-    pipeline.deploy_component([dataio_0, intersection_0, hetero_lr_0])
+    pipeline.deploy_component([data_transform_0, intersection_0, hetero_lr_0])
 
     # initiate predict pipeline
     predict_pipeline = PipeLine()
@@ -113,8 +114,8 @@ def main():
     predict_pipeline.add_component(reader_2)
     # add selected components from train pipeline onto predict pipeline
     # specify data source
-    predict_pipeline.add_component(pipeline,
-                                   data=Data(predict_input={pipeline.dataio_0.input.data: reader_2.output.data}))
+    predict_pipeline.add_component(pipeline, data=Data(
+        predict_input={pipeline.data_transform_0.input.data: reader_2.output.data}))
     # run predict model
     predict_pipeline.predict()
 
