@@ -32,9 +32,13 @@ class TransformParam(BaseParam):
         Specify which columns need to be transform. If column index is None, None of columns will be transformed.
         If it is -1, it will use same columns as cols in binning module.
 
+        Note tha columns specified by `transform_cols` and `transform_names` will be combined.
+
     transform_names: list of string, default: []
         Specify which columns need to calculated. Each element in the list represent for a column name in header.
 
+        Note tha columns specified by `transform_cols` and `transform_names` will be combined.
+
 
     transform_type: str, 'bin_num'or 'woe' or None default: 'bin_num'
         Specify which value these columns going to replace.
@@ -153,9 +157,13 @@ class FeatureBinningParam(BaseParam):
         Specify which columns need to be binned. -1 represent for all columns. If you need to indicate specific
         cols, provide a list of header index instead of -1.
 
+        Note tha columns specified by `bin_indexes` and `bin_names` will be combined.
+
     bin_names : list of string, default: []
         Specify which columns need to calculated. Each element in the list represent for a column name in header.
 
+        Note tha columns specified by `bin_indexes` and `bin_names` will be combined.
+
     adjustment_factor : float, default: 0.5
         the adjustment factor when calculating WOE. This is useful when there is no event or non-event in
         a bin. Please note that this parameter will NOT take effect for setting in host.
@@ -167,9 +175,13 @@ class FeatureBinningParam(BaseParam):
 
         The number of categories should not exceed bin_num set above.
 
+        Note tha columns specified by `category_indexes` and `category_names` will be combined.
+
     category_names : list of string, default: []
         Use column names to specify category features. Each element in the list represent for a column name in header.
 
+        Note tha columns specified by `category_indexes` and `category_names` will be combined.
+
     local_only : bool, default: False
         Whether just provide binning method to guest party. If true, host party will do nothing.
         Warnings: This parameter will be deprecated in future version.
@@ -229,15 +241,33 @@ class FeatureBinningParam(BaseParam):
 
 
 class HeteroFeatureBinningParam(FeatureBinningParam):
-    def __init__(self, method=consts.QUANTILE,
-                 compress_thres=consts.DEFAULT_COMPRESS_THRESHOLD,
+    """
+    split_points_by_index: dict, default None
+        Manually specified split points for local features;
+        key should be feature index, value should be split points in sorted list;
+        along with `split_points_by_col_name`, keys should cover all local features, including categorical features;
+        note that each split point list should have length equal to desired bin num(n),
+        with first (n-1) entries equal to the maximum value(inclusive) of each first (n-1) bins,
+        and nth value the max of current feature.
+
+    split_points_by_col_name: dict, default None
+        Manually specified split points for local features;
+        key should be feature name, value should be split points in sorted list;
+        along with `split_points_by_index`, keys should cover all local features, including categorical features;
+        note that each split point list should have length equal to desired bin num(n),
+        with first (n-1) entries equal to the maximum value(inclusive) of each first (n-1) bins,
+        and nth value the max of current feature.
+    """
+
+    def __init__(self, method=consts.QUANTILE, compress_thres=consts.DEFAULT_COMPRESS_THRESHOLD,
                  head_size=consts.DEFAULT_HEAD_SIZE,
                  error=consts.DEFAULT_RELATIVE_ERROR,
                  bin_num=consts.G_BIN_NUM, bin_indexes=-1, bin_names=None, adjustment_factor=0.5,
                  transform_param=TransformParam(), optimal_binning_param=OptimalBinningParam(),
                  local_only=False, category_indexes=None, category_names=None,
                  encrypt_param=EncryptParam(),
-                 need_run=True, skip_static=False):
+                 need_run=True, skip_static=False,
+                 split_points_by_index=None, split_points_by_col_name=None):
         super(HeteroFeatureBinningParam, self).__init__(method=method, compress_thres=compress_thres,
                                                         head_size=head_size, error=error,
                                                         bin_num=bin_num, bin_indexes=bin_indexes,
@@ -249,6 +279,8 @@ class HeteroFeatureBinningParam(FeatureBinningParam):
                                                         skip_static=skip_static)
         self.optimal_binning_param = copy.deepcopy(optimal_binning_param)
         self.encrypt_param = encrypt_param
+        self.split_points_by_index = split_points_by_index
+        self.split_points_by_col_name = split_points_by_col_name
 
     def check(self):
         descr = "Hetero Binning param's"
