@@ -165,78 +165,41 @@ class HomoLogisticParam(LogisticParam):
     """
     Parameters
     ----------
-    re_encrypt_batches : int, default: 2
-        Required when using encrypted version HomoLR. Since multiple batch updating coefficient may cause
-        overflow error. The model need to be re-encrypt for every several batches. Please be careful when setting
-        this parameter. Too large batches may cause training failure.
-
     aggregate_iters : int, default: 1
         Indicate how many iterations are aggregated once.
-
-    use_proximal: bool, default: False
-        Whether to turn on additional proximial term. For more details of FedProx, Please refer to
-        https://arxiv.org/abs/1812.06127
-
-    mu: float, default 0.1
-        To scale the proximal term
-
     """
 
     def __init__(self, penalty='L2',
                  tol=1e-4, alpha=1.0, optimizer='rmsprop',
                  batch_size=-1, learning_rate=0.01, init_param=InitParam(),
                  max_iter=100, early_stop='diff',
-                 encrypt_param=EncryptParam(method=None), re_encrypt_batches=2,
                  predict_param=PredictParam(), cv_param=CrossValidationParam(),
                  decay=1, decay_sqrt=True,
                  aggregate_iters=1, multi_class='ovr', validation_freqs=None,
-                 early_stopping_rounds=None,
                  metrics=['auc', 'ks'],
-                 use_first_metric_only=False,
-                 use_proximal=False,
-                 mu=0.1, callback_param=CallbackParam()
+                 callback_param=CallbackParam()
                  ):
+
         super(HomoLogisticParam, self).__init__(penalty=penalty, tol=tol, alpha=alpha, optimizer=optimizer,
                                                 batch_size=batch_size,
                                                 learning_rate=learning_rate,
                                                 init_param=init_param, max_iter=max_iter, early_stop=early_stop,
-                                                encrypt_param=encrypt_param, predict_param=predict_param,
+                                                predict_param=predict_param,
                                                 cv_param=cv_param, multi_class=multi_class,
                                                 validation_freqs=validation_freqs,
                                                 decay=decay, decay_sqrt=decay_sqrt,
-                                                early_stopping_rounds=early_stopping_rounds,
-                                                metrics=metrics, use_first_metric_only=use_first_metric_only,
+                                                metrics=metrics,
                                                 callback_param=callback_param)
-        self.re_encrypt_batches = re_encrypt_batches
         self.aggregate_iters = aggregate_iters
-        self.use_proximal = use_proximal
-        self.mu = mu
 
     def check(self):
-        super().check()
-        if type(self.re_encrypt_batches).__name__ != "int":
-            raise ValueError(
-                "logistic_param's re_encrypt_batches {} not supported, should be int type".format(
-                    self.re_encrypt_batches))
-        elif self.re_encrypt_batches < 0:
-            raise ValueError(
-                "logistic_param's re_encrypt_batches must be greater or equal to 0")
 
+        super().check()
         if not isinstance(self.aggregate_iters, int):
             raise ValueError(
                 "logistic_param's aggregate_iters {} not supported, should be int type".format(
                     self.aggregate_iters))
 
-        if self.encrypt_param.method == consts.PAILLIER:
-            if self.optimizer != 'sgd':
-                raise ValueError("Paillier encryption mode supports 'sgd' optimizer method only.")
-
-            if self.penalty == consts.L1_PENALTY:
-                raise ValueError("Paillier encryption mode supports 'L2' penalty or None only.")
-
-        if self.optimizer == 'sqn':
-            raise ValueError("'sqn' optimizer is supported for hetero mode only.")
-
         return True
 
 
