@@ -23,7 +23,6 @@ from pathlib import Path
 
 from flow_sdk.client import FlowClient
 from pipeline.backend import config as conf
-from pipeline.backend.config import IODataType
 from pipeline.backend.config import JobStatus
 from pipeline.backend.config import StatusCode
 from pipeline.utils.logger import LOGGER
@@ -31,47 +30,20 @@ from pipeline.utils.logger import LOGGER
 
 class JobInvoker(object):
     def __init__(self):
-        self.client = FlowClient(ip=conf.FlowConfig.IP, port=conf.FlowConfig.PORT, version=conf.SERVER_VERSION,
-                                 app_key=conf.FlowConfig.APP_KEY, secret_key=conf.FlowConfig.SECRET_KEY)
+        self.client = FlowClient(ip=conf.PipelineConfig.IP, port=conf.PipelineConfig.PORT, version=conf.SERVER_VERSION,
+                                 app_key=conf.PipelineConfig.APP_KEY, secret_key=conf.PipelineConfig.SECRET_KEY)
 
     def submit_job(self, dsl=None, submit_conf=None, callback_func=None):
-        """
-        dsl_path = None
-        with tempfile.TemporaryDirectory() as job_dir:
-            if dsl:
-                dsl_path = os.path.join(job_dir, "job_dsl.json")
-                # pprint.pprint(dsl)
-                LOGGER.debug(f"submit dsl is: \n {json.dumps(dsl, indent=4, ensure_ascii=False)}")
-                with open(dsl_path, "w") as fout:
-                    fout.write(json.dumps(dsl))
-            LOGGER.debug(f"submit conf is: \n {json.dumps(submit_conf, indent=4, ensure_ascii=False)}")
-            submit_path = os.path.join(job_dir, "job_runtime_conf.json")
-            with open(submit_path, "w") as fout:
-                fout.write(json.dumps(submit_conf))
-
-            result = self.client.job.submit(conf_path=submit_path, dsl_path=dsl_path)
-            if callback_func is not None:
-                callback_func(result)
-            try:
-                if 'retcode' not in result or result["retcode"] != 0:
-                    raise ValueError(f"retcode err")
-
-                if "jobId" not in result:
-                    raise ValueError(f"jobID not in result: {result}")
-
-                job_id = result["jobId"]
-                data = result["data"]
-            except ValueError:
-                raise ValueError("job submit failed, err msg: {}".format(result))
-        """
         LOGGER.debug(f"submit dsl is: \n {json.dumps(dsl, indent=4, ensure_ascii=False)}")
         LOGGER.debug(f"submit conf is: \n {json.dumps(submit_conf, indent=4, ensure_ascii=False)}")
-        result = self.client.job.submit(config_data=submit_conf, dsl_data=dsl)
+        result = self.run_job_with_retry(self.client.job.submit, params=dict(config_data=submit_conf,
+                                                                             dsl_data=dsl))
+        # result = self.client.job.submit(config_data=submit_conf, dsl_data=dsl)
         if callback_func is not None:
             callback_func(result)
         try:
             if 'retcode' not in result or result["retcode"] != 0:
-                raise ValueError(f"retcode err")
+                raise ValueError(f"retcode err, callback result is {result}")
 
             if "jobId" not in result:
                 raise ValueError(f"jobID not in result: {result}")
@@ -83,25 +55,6 @@ class JobInvoker(object):
         return job_id, data
 
     def upload_data(self, submit_conf=None, drop=0):
-        """
-        with tempfile.TemporaryDirectory() as job_dir:
-            submit_path = os.path.join(job_dir, "job_runtime_conf.json")
-            with open(submit_path, "w") as fout:
-                fout.write(json.dumps(submit_conf))
-
-            result = self.client.data.upload(conf_path=submit_path, verbose=1, drop=drop)
-            try:
-                if 'retcode' not in result or result["retcode"] != 0:
-                    raise ValueError
-
-                if "jobId" not in result:
-                    raise ValueError
-
-                job_id = result["jobId"]
-                data = result["data"]
-            except:
-                raise ValueError("job submit failed, err msg: {}".format(result))
-        """
         result = self.client.data.upload(config_data=submit_conf, verbose=1, drop=drop)
         try:
             if 'retcode' not in result or result["retcode"] != 0:
@@ -116,7 +69,14 @@ class JobInvoker(object):
             raise ValueError("job submit failed, err msg: {}".format(result))
         return job_id, data
 
-    def monitor_job_status(self, job_id, role, party_id):
+    def monitor_job_status(self, job_id, role, party_id, previous_status=None):
+        if previous_status in [StatusCode.SUCCESS, StatusCode.CANCELED]:
+            if previous_status == StatusCode.SUCCESS:
+                status = JobStatus.SUCCESS
+            else:
+                status = JobStatus.CANCELED
+            raise ValueError(f"Previous fit status is {status}, please don't fit again")
+
         party_id = str(party_id)
         start_time = time.time()
         pre_cpn = None
@@ -125,33 +85,25 @@ class JobInvoker(object):
             ret_code, ret_msg, data = self.query_job(job_id, role, party_id)
             status = data["f_status"]
             if status == JobStatus.SUCCESS:
-                # print("job is success!!!")
                 elapse_seconds = timedelta(seconds=int(time.time() - start_time))
-                # sys.stdout.write(f"\n\r")
                 LOGGER.info(f"Job is success!!! Job id is {job_id}")
                 LOGGER.info(f"Total time: {elapse_seconds}")
                 return StatusCode.SUCCESS
 
             elif status == JobStatus.FAILED:
-                # sys.stdout.write(f"\n\r")
-                # LOGGER.info(f"\n\r")
                 raise ValueError(f"Job is failed, please check out job {job_id} by fate board or fate_flow cli")
 
             elif status == JobStatus.WAITING:
                 elapse_seconds = timedelta(seconds=int(time.time() - start_time))
-                # sys.stdout.write(f"\r")
-                # sys.stdout.flush()
                 LOGGER.info(f"\x1b[80D\x1b[1A\x1b[KJob is still waiting, time elapse: {elapse_seconds}")
 
             elif status == JobStatus.CANCELED:
                 elapse_seconds = timedelta(seconds=int(time.time() - start_time))
-                # sys.stdout.write(f"\n\r")
                 LOGGER.info(f"Job is canceled, time elapse: {elapse_seconds}\r")
                 return StatusCode.CANCELED
 
             elif status == JobStatus.TIMEOUT:
                 elapse_seconds = timedelta(seconds=int(time.time() - start_time))
-                # sys.stdout.write(f"\n\r")
                 raise ValueError(f"Job is timeout, time elapse: {elapse_seconds}\r")
 
             elif status == JobStatus.RUNNING:
@@ -172,8 +124,6 @@ class JobInvoker(object):
                 if cpn != pre_cpn:
                     LOGGER.info(f"\r")
                     pre_cpn = cpn
-                # sys.stdout.write(f"\r")
-                # sys.stdout.flush()
                 LOGGER.info(f"\x1b[80D\x1b[1A\x1b[KRunning component {cpn}, time elapse: {elapse_seconds}")
 
             else:
@@ -183,7 +133,9 @@ class JobInvoker(object):
 
     def query_job(self, job_id, role, party_id):
         party_id = str(party_id)
-        result = self.client.job.query(job_id=job_id, role=role, party_id=party_id)
+        result = self.run_job_with_retry(self.client.job.query, params=dict(job_id=job_id, role=role,
+                                                                            party_id=party_id))
+        # result = self.client.job.query(job_id=job_id, role=role, party_id=party_id)
         try:
             if 'retcode' not in result or result["retcode"] != 0:
                 raise ValueError("can not query_job")
@@ -236,10 +188,10 @@ class JobInvoker(object):
         data = {}
         try:
             if 'retcode' not in result or result["retcode"] != 0:
-                raise ValueError
+                raise ValueError(f"No retcode found in result: {result}")
 
             if "data" not in result:
-                raise ValueError
+                raise ValueError(f"No data returned: {result}")
 
             all_data = result["data"]
             n = len(all_data)
@@ -259,7 +211,7 @@ class JobInvoker(object):
                 LOGGER.info(f"No output data table found in {result}")
 
         except ValueError:
-            raise ValueError("Job submit failed, err msg: {}".format(result))
+            raise ValueError(f"Job submit failed, err msg: {result}")
         return data
 
     def query_task(self, job_id, role, party_id, status=None):
@@ -281,7 +233,7 @@ class JobInvoker(object):
         except ValueError:
             raise ValueError("Query task result is {}, cannot parse useful info".format(result))
 
-    def get_output_data(self, job_id, cpn_name, role, party_id, limits=None):
+    def get_output_data(self, job_id, cpn_name, role, party_id, limits=None, to_pandas=True):
         """
 
         Parameters
@@ -291,30 +243,16 @@ class JobInvoker(object):
         role: str
         party_id: int
         limits: int, None, default None. Maximum number of lines returned, including header. If None, return all lines.
+        to_pandas: bool, default True. Change data output to pandas or not.
 
         Returns
         -------
-        dict
-        single output example:
-            {
-                data: [],
-                meta: []
-
-            }
+        single output example: pandas.DataFrame
         multiple output example:
             {
-            train_data: {
-                data: [],
-                meta: []
-                },
-            validate_data: {
-                data: [],
-                meta: []
-                }
-            test_data: {
-                data: [],
-                meta: []
-                }
+            train_data: tran_data_df,
+            validate_data: validate_data_df,
+            test_data: test_data_df
             }
         """
         party_id = str(party_id)
@@ -323,21 +261,28 @@ class JobInvoker(object):
                                                        party_id=party_id, component_name=cpn_name)
             output_dir = result["directory"]
             n = 0
+
+            data_files = []
             for file in os.listdir(output_dir):
                 if file.endswith("csv"):
                     n += 1
+                    data_files.append(file[:-4])
 
             if n > 0:
                 data_dict = {}
-                for data_name in [IODataType.SINGLE, IODataType.TRAIN, IODataType.VALIDATE, IODataType.TEST]:
+                for data_name in data_files:
                     curr_data_dict = JobInvoker.create_data_meta_dict(data_name, output_dir, limits)
                     if curr_data_dict is not None:
-                        data_dict[data_name] = curr_data_dict
+                        if to_pandas:
+                            data_dict[data_name] = self.to_pandas(curr_data_dict)
+                        else:
+                            data_dict[data_name] = curr_data_dict
             # no output data obtained
             else:
                 raise ValueError(f"No output data found in directory{output_dir}")
             if len(data_dict) == 1:
                 return list(data_dict.values())[0]
+
             return data_dict
 
     @staticmethod
@@ -354,6 +299,42 @@ class JobInvoker(object):
         data_dict = {"data": data, "meta": meta}
         return data_dict
 
+    @staticmethod
+    def to_pandas(data_dict):
+        import pandas as pd
+        data = data_dict["data"]
+        meta = data_dict["meta"]
+
+        if JobInvoker.is_normal_predict_task(meta):
+            """ignore the first line
+            """
+            rows = []
+            for i in range(1, len(data)):
+                cols = data[i].split(",", -1)
+                predict_detail = json.loads(",".join(cols[len(meta) - 2: -1])[1:-1].replace("\'", "\""))
+                value = cols[: len(meta) - 2] + [predict_detail] + cols[-1:]
+                rows.append(value)
+
+            return pd.DataFrame(rows, columns=meta)
+        else:
+            rows = []
+            for i in range(1, len(data)):
+                cols = data[i].split(",", -1)
+                rows.append(cols)
+            return pd.DataFrame(rows, columns=meta)
+
+    @staticmethod
+    def is_normal_predict_task(col_names):
+        if len(col_names) <= 5:
+            return False
+
+        template_col_names = ["label", "predict_result", "predict_score", "predict_detail", "type"]
+        for i in range(5):
+            if template_col_names[i] != col_names[-5 + i]:
+                return False
+
+        return True
+
     @staticmethod
     def extract_output_data(output_data, limits):
         data = []
@@ -370,8 +351,8 @@ class JobInvoker(object):
             try:
                 meta_dict = json.load(fin)
                 meta = meta_dict["header"]
-            except ValueError:
-                raise ValueError(f"Cannot get output data meta. err msg: ")
+            except ValueError as e:
+                raise ValueError(f"Cannot get output data meta. err msg: {e}")
 
         return meta
 
@@ -382,11 +363,10 @@ class JobInvoker(object):
             result = self.client.component.output_model(job_id=job_id, role=role,
                                                         party_id=party_id, component_name=cpn_name)
             if "data" not in result:
-                raise ValueError(f"job {job_id}, component {cpn_name} has no output model param")
+                raise ValueError(f"{result['retmsg']} job {job_id}, component {cpn_name} has no output model param")
             return result["data"]
         except BaseException:
-            raise ValueError("Cannot get output model, err msg: ")
-            # raise
+            raise ValueError(f"Cannot get output model, err msg: {result}")
 
     def get_metric(self, job_id, cpn_name, role, party_id):
         result = None
@@ -398,7 +378,7 @@ class JobInvoker(object):
                 raise ValueError(f"job {job_id}, component {cpn_name} has no output metric")
             return result["data"]
         except BaseException:
-            raise ValueError("Cannot get ouput model, err msg: ")
+            raise ValueError(f"Cannot get output model, err msg: {result}")
             # raise
 
     def get_summary(self, job_id, cpn_name, role, party_id):
@@ -408,11 +388,10 @@ class JobInvoker(object):
             result = self.client.component.get_summary(job_id=job_id, role=role,
                                                        party_id=party_id, component_name=cpn_name)
             if "data" not in result:
-                # print("job {}, component {} has no output metric".format(job_id, cpn_name))
                 raise ValueError(f"Job {job_id}, component {cpn_name} has no output metric")
             return result["data"]
         except BaseException:
-            raise ValueError("Cannot get output model, err msg: ")
+            raise ValueError(f"Cannot get output model, err msg: {result}")
 
     def model_deploy(self, model_id, model_version, cpn_list=None, predict_dsl=None, components_checkpoint=None):
         if cpn_list:
@@ -427,7 +406,7 @@ class JobInvoker(object):
         if result is None or 'retcode' not in result:
             raise ValueError("Call flow deploy is failed, check if fate_flow server is up!")
         elif result["retcode"] != 0:
-            raise ValueError("Cannot deploy components, error msg is {}".format(result["retmsg"]))
+            raise ValueError(f"Cannot deploy components, error msg is {result['data']}")
         else:
             return result["data"]
 
@@ -441,13 +420,6 @@ class JobInvoker(object):
             return result["data"]
 
     def load_model(self, load_conf):
-        """
-        with tempfile.TemporaryDirectory() as job_dir:
-            submit_path = os.path.join(job_dir, "job_runtime_conf.json")
-            with open(submit_path, "w") as fout:
-                fout.write(json.dumps(load_conf))
-        result = self.client.model.load(submit_path)
-        """
         result = self.client.model.load(load_conf)
         if result is None or 'retcode' not in result:
             raise ValueError("Call flow load failed, check if fate_flow server is up!")
@@ -457,13 +429,6 @@ class JobInvoker(object):
             return result["data"]
 
     def bind_model(self, bind_conf):
-        """
-        with tempfile.TemporaryDirectory() as job_dir:
-            submit_path = os.path.join(job_dir, "job_runtime_conf.json")
-            with open(submit_path, "w") as fout:
-                fout.write(json.dumps(bind_conf))
-        result = self.client.model.bind(submit_path)
-        """
         result = self.client.model.bind(bind_conf)
         if result is None or 'retcode' not in result:
             raise ValueError("Call flow bind failed, check if fate_flow server is up!")
@@ -473,13 +438,6 @@ class JobInvoker(object):
             return result["retmsg"]
 
     def convert_homo_model(self, convert_conf):
-        """
-        with tempfile.TemporaryDirectory() as job_dir:
-            submit_path = os.path.join(job_dir, "job_runtime_conf.json")
-            with open(submit_path, "w") as fout:
-                fout.write(json.dumps(convert_conf))
-        result = self.client.model.homo_convert(submit_path)
-        """
         result = self.client.model.homo_convert(convert_conf)
         if result is None or 'retcode' not in result:
             raise ValueError("Call flow homo convert failed, check if fate_flow server is up!")
@@ -487,3 +445,34 @@ class JobInvoker(object):
             raise ValueError("Cannot convert homo model, error msg is {}".format(result["retmsg"]))
         else:
             return result["data"]
+
+    def bind_table(self, **kwargs):
+        result = self.client.table.bind(**kwargs)
+        if result is None or 'retcode' not in result:
+            raise ValueError("Call flow table bind is failed, check if fate_flow server is up!")
+        elif result["retcode"] != 0:
+            raise ValueError(f"Cannot bind table, error msg is {result['retmsg']}")
+        else:
+            return result["data"]
+
+    @staticmethod
+    def run_job_with_retry(api_func, params):
+        for i in range(conf.MAX_RETRY + 1):
+            try:
+                result = api_func(**params)
+                if result is None or "retmsg" not in result:
+                    return result
+
+                if i == conf.MAX_RETRY:
+                    return result
+
+                ret_msg = result["retmsg"]
+                if "connection refused" in ret_msg.lower() \
+                        or "max retries" in ret_msg.lower():
+                    pass
+                else:
+                    return result
+            except AttributeError:
+                pass
+
+            time.sleep(conf.TIME_QUERY_FREQS * (i + 1))
